Specific IMNN classes
=====================

.. contents:: The available modules are:
   :depth: 2
   :local:

SimulatorIMNN
-------------

SimulatorIMNN
_____________

.. autoclass:: imnn.SimulatorIMNN
  :members:

  .. autoclasstoc::

AggregatedSimulatorIMNN
_______________________

.. autoclass:: imnn.AggregatedSimulatorIMNN
  :members:

  .. autoclasstoc::

GradientIMNN
------------

GradientIMNN
____________

.. autoclass:: imnn.GradientIMNN
  :members:

  .. autoclasstoc::

AggregatedGradientIMNN
______________________

.. autoclass:: imnn.AggregatedGradientIMNN
  :members:

  .. autoclasstoc::

NumericalGradientIMNN
---------------------

NumericalGradientIMNN
_____________________

.. autoclass:: imnn.NumericalGradientIMNN
  :members:

  .. autoclasstoc::

AggregatedNumericalGradientIMNN
_______________________________

.. autoclass:: imnn.AggregatedNumericalGradientIMNN
  :members:
